==> bitcoin-0.21.1.knots20210629.tar.gz: bitcoin-0.21.1.knots20210629/src/qt/locale/bitcoin_ky.ts <==
<TS language="ky" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Жаң даректи жасоо</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Ө&amp;чүрүү</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation>Дарек</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(аты жок)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Транзакциялар</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Капчык:</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>Билдирүүнү &amp;текшерүү...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Жөнөтүү</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Жардам</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ката</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Эскертүү</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Маалымат</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Жаңыланган</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Терезе</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(аты жок)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation>Капчык</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Дарек</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>версия</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ката</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Дарек</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Даректи алмашуу буферинен коюу</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Тармак</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>Капчык</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Порт:</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Терезе</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Жарайт</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Жокко чыгаруу</translation>
    </message>
    <message>
        <source>default</source>
        <translation>жарыяланбаган</translation>
    </message>
    <message>
        <source>none</source>
        <translation>жок</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ката</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Txn</source>
        <comment>Tx Watch: Transaction type abbreviation</comment>
        <translation>транзакция</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Маалымат</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Жалпы</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>&amp;Тармак</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Аты</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Капчык: </translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Ачуу</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Консоль</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Консолду тазалоо</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Message:</source>
        <translation>Билдирүү:</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Дарек:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Билдирүү:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Капчык:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Билдирүү</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(аты жок)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Бардыгын тазалоо</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Жөнөтүү</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">Жөнөтүү</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(аты жок)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Даректи алмашуу буферинен коюу</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Билдирүү:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Даректи алмашуу буферинен коюу</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Бардыгын тазалоо</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Билдирүү</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>транзакция</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(аты жок)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Дарек</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>Error</source>
        <translation>Ката</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Жокко чыгаруу</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>Ката</translation>
    </message>
    </context>
</TS>

==> bitcoin-21.2.knots20210629.tar.gz: bitcoin-21.2.knots20210629/src/qt/locale/bitcoin_ky.ts <==
<TS language="ky" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Жаң даректи жасоо</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Ө&amp;чүрүү</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation>Дарек</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(аты жок)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Транзакциялар</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Капчык:</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>Билдирүүнү &amp;текшерүү...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Жөнөтүү</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Жардам</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ката</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Эскертүү</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Маалымат</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Жаңыланган</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Терезе</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(аты жок)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation>Капчык</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Дарек</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>версия</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>Ката</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Дарек</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Даректи алмашуу буферинен коюу</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Тармак</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>Капчык</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Порт:</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Терезе</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Жарайт</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Жокко чыгаруу</translation>
    </message>
    <message>
        <source>default</source>
        <translation>жарыяланбаган</translation>
    </message>
    <message>
        <source>none</source>
        <translation>жок</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ката</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Txn</source>
        <comment>Tx Watch: Transaction type abbreviation</comment>
        <translation>транзакция</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Маалымат</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Жалпы</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>&amp;Тармак</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Аты</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Капчык: </translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Ачуу</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Консоль</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Консолду тазалоо</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Message:</source>
        <translation>Билдирүү:</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Дарек:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Билдирүү:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Капчык:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Билдирүү</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(аты жок)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Бардыгын тазалоо</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Жөнөтүү</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">Жөнөтүү</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(аты жок)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Даректи алмашуу буферинен коюу</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Билдирүү:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Даректи алмашуу буферинен коюу</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Бардыгын тазалоо</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>Билдирүүнү &amp;текшерүү</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation type="unfinished">Билдирүүнү &amp;текшерүү</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Билдирүү</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>транзакция</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(аты жок)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Дарек</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation>Ката</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Жокко чыгаруу</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>Ката</translation>
    </message>
    </context>
</TS>
